@@ -1,9 +1,9 @@
 package TableData::Object::Base;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-29'; # DATE
+our $DATE = '2021-01-10'; # DATE
 our $DIST = 'TableData-Object'; # DIST
-our $VERSION = '0.112'; # VERSION
+our $VERSION = '0.113'; # VERSION
 
 use 5.010;
 use strict;
@@ -242,7 +242,7 @@ TableData::Object::Base - Base class for TableData::Object::*
 
 =head1 VERSION
 
-This document describes version 0.112 of TableData::Object::Base (from Perl distribution TableData-Object), released on 2020-05-29.
+This document describes version 0.113 of TableData::Object::Base (from Perl distribution TableData-Object), released on 2021-01-10.
 
 =head1 METHODS
 
@@ -384,7 +384,8 @@ rows and has a defined and unique value across all rows. Example:
      {a=>1, b=>2, c=>undef, d=>1},
      {      b=>2, c=>3,     d=>2},
      {a=>1, b=>3, c=>4,     d=>3},
- ]); # -> ('d')
+ ]);
+ my @colnames = $td->uniq_col_names; # -> ('d')
 
 In the above example, C<a> does not exist in the second hash, <b> is not unique,
 and C<c> has an undef value in the the first hash.
@@ -399,7 +400,8 @@ Example:
      {a=>1, b=>2, c=>undef, d=>2},
      {      b=>2, c=>undef, d=>2},
      {a=>2, b=>3, c=>undef, d=>2},
- ]); # -> ('c', 'd')
+ ]);
+ my @colnames = $td->const_col_names; # -> ('c', 'd')
 
 In the above example, C<a> does not exist in the second hash, <b> has two
 different values.
@@ -461,7 +463,7 @@ Source repository is at L<https://github.com/perlancar/perl-TableData-Object>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableData-Object>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-TableData-Object/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -473,7 +475,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
